@@ -5,6 +5,7 @@ import sys
 import traceback
 import logging
 from qds_ops.entities.web import Web
+from qds_ops.entities.log import Log
 from qds_ops.entities.oozie_master import OozieMaster
 from qds_ops.entities.oozie_slave import OozieSlave
 from qds_ops.entities.oozie import Oozie
@@ -24,6 +25,7 @@ def main():
 
     chef = Chef(subparsers)
     web = Web(subparsers)
+    log = Log(subparsers)
     master = OozieMaster(subparsers)
     slave = OozieSlave(subparsers)
     oozie = Oozie(subparsers)
